@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package WebService::RTMAgent;
 # ABSTRACT: a user agent for the Remember The Milk API
-$WebService::RTMAgent::VERSION = '0.601';
+$WebService::RTMAgent::VERSION = '0.602';
 #pod =head1 SYNOPSIS
 #pod
 #pod  $ua = WebService::RTMAgent->new;
@@ -109,10 +109,11 @@ our $config;  # reference to config hash
 #pod =cut
 
 sub new {
-    my ($class) = @_;
-    my $self = bless {}, $class;
+    my $class = shift;
+    Carp::confess("tried to call ->new on an instance") if ref $class;
+    my $self  = $class->SUPER::new(@_);
     $self->verbose('');
-    return $self;
+    return bless $self, $class;
 }
 
 #pod =head2 $ua->api_key($key);
@@ -380,7 +381,7 @@ WebService::RTMAgent - a user agent for the Remember The Milk API
 
 =head1 VERSION
 
-version 0.601
+version 0.602
 
 =head1 SYNOPSIS
 
@@ -568,6 +569,26 @@ L<XML::Simple>
 
 Yves Rutschle
 
+=head1 CONTRIBUTORS
+
+=for stopwords Ed Santiago Ricardo Signes Yves Rutschle
+
+=over 4
+
+=item *
+
+Ed Santiago <ed@edsantiago.com>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=item *
+
+Yves Rutschle <CENSORED>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2008 by Yves Rutschle.
